/*
    Copyright (C) 2004 Trolltech AS. All Rights Reserved.

    This file ("Example Code"), is part of an example program for Qt,
    and is licensed under the Qt Commercial License Agreement,
    Agreement version 2.4 and higher as well as under the GPL.

    The Example Code is licensed to you "as is" without warranty of
    any kind. To the maximum extent permitted by applicable law,
    Trolltech on behalf of itself and its suppliers, disclaims all
    warranties express or implied, including, but not limited to,
    implied warranties of merchantability and fitness for a particular
    purpose with regard to the Example Code. Trolltech does not
    warrant that the Example Code will satisfy your requirements or
    that it is without defect or error or that the operation thereof
    will be uninterrupted. All use of and reliance on the Example Code
    is at the sole risk of and responsibility of you and your
    customers.

    If you are a holder of a Qt Commercial License Agreement, you can
    use the code under that agreement or you can use it under GPL. If
    you are not a holder of a Qt Commercial License Agreement, you can
    use the code under the GPL. Regardless of the applicable license
    agreement, the Example Code may be used, distributed and modified
    without limitation.
*/

#include "palettemodelmanager.h"

PaletteModelManager *PaletteModelManager::theManager = 0;

PaletteModelManager *PaletteModelManager::getInstance()
{
    if (!theManager)
        theManager = new PaletteModelManager();
    return theManager;
}

PaletteModelManager::~PaletteModelManager()
{
    if (theManager == this)
        theManager = 0;
}

QColor PaletteModelManager::getColor(const QString &id) const
{
    if (thePalette.contains(id))
        return thePalette[id];
    return QColor(); // invalid color
}

QString PaletteModelManager::addColor(const QString &id, const QColor &color)
{
    QString newId = id;
    while (thePalette.contains(newId))
        newId += tr("_1"); // simple algorithm for generating unique id
    thePalette[newId] = color;
    emit colorAdded(newId);
    return newId;
}

void PaletteModelManager::changeColor(const QString &id, const QColor &newColor)
{
    if (!thePalette.contains(id))
        return; // cannot change a color because palette doesn't contains such an id
    if (thePalette[id] == newColor)
        return; // color in palette is equal to newColor
    emit colorChanged(id, newColor);
    thePalette[id] = newColor;
}

void PaletteModelManager::removeColor(const QString &id)
{
    if (!thePalette.contains(id))
        return; // cannot remove a color because palette doesn't contains such an id
    emit colorRemoved(id);
    thePalette.remove(id);
}
