/*
    Copyright (C) 2004 Trolltech AS. All Rights Reserved.

    This file ("Example Code"), is part of an example program for Qt,
    and is licensed under the Qt Commercial License Agreement,
    Agreement version 2.4 and higher as well as under the GPL.

    The Example Code is licensed to you "as is" without warranty of
    any kind. To the maximum extent permitted by applicable law,
    Trolltech on behalf of itself and its suppliers, disclaims all
    warranties express or implied, including, but not limited to,
    implied warranties of merchantability and fitness for a particular
    purpose with regard to the Example Code. Trolltech does not
    warrant that the Example Code will satisfy your requirements or
    that it is without defect or error or that the operation thereof
    will be uninterrupted. All use of and reliance on the Example Code
    is at the sole risk of and responsibility of you and your
    customers.

    If you are a holder of a Qt Commercial License Agreement, you can
    use the code under that agreement or you can use it under GPL. If
    you are not a holder of a Qt Commercial License Agreement, you can
    use the code under the GPL. Regardless of the applicable license
    agreement, the Example Code may be used, distributed and modified
    without limitation.
*/

#ifndef PALETTEMODELMANAGER_H
#define PALETTEMODELMANAGER_H

#include <qcolor.h>
#include <qmap.h>
#include <qobject.h>

class PaletteModelManager : public QObject
{
    Q_OBJECT

public:
    ~PaletteModelManager();

    static PaletteModelManager *getInstance();

    QMap<QString, QColor> getPalette() const { return thePalette; }
    QColor getColor(const QString &id) const;

public slots:
    QString addColor(const QString &id, const QColor &color);
    void changeColor(const QString &id, const QColor &newColor);
    void removeColor(const QString &id);

signals:
    void colorAdded(const QString &id);
    void colorChanged(const QString &id, const QColor &color);
    void colorRemoved(const QString &id);

private:
    PaletteModelManager(QObject *parent = 0, const char *name = 0)
        : QObject(parent, name) {}

    QMap<QString, QColor> thePalette;
    static PaletteModelManager *theManager;
};

#endif
